-- setting the number of parallel mapred tasks

SET default_parallel 100;
SET mapred.job.map.memory.mb 2048;
SET mapred.job.reduce.memory.mb 2048;

SET mapred.compress.map.output true;
SET mapred.output.compression org.apache.hadoop.io.compress.GzipCodec;


SIMWORDS = LOAD '$sim' USING PigStorage('\t')  as (word1: chararray, word2:chararray, simscore : float); 

WFC = LOAD '$wfc' USING PigStorage('\t')  as (wfc_word: chararray, wfc_feature: chararray, wfc_count: float);

WT1 = LOAD '$weight' USING PigStorage('\t')  as (w1_word: chararray, w1_feature: chararray, w1_score: float);
WT2 = LOAD '$weight' USING PigStorage('\t')  as (w2_word: chararray, w2_feature: chararray, w2_score: float);
W1 = FILTER WT1 BY w1_score >=0;
W2 = FILTER WT2 BY w2_score >=0;

T2 = JOIN SIMWORDS BY word1, W1 BY w1_word;
T3 = JOIN T2 BY (word2,w1_feature), W2 BY (w2_word, w2_feature);

T4 = FOREACH T3 GENERATE w1_word, w2_word, w1_feature,w1_score,w2_score, (w1_score<w2_score?w1_score:w2_score) as min_score;

G1 = GROUP T4 BY (w1_word,w2_word);

G2 = FOREACH G1 GENERATE FLATTEN(group) AS (G1::w1_word,G1::w2_word), 2*SUM(T4.min_score)/(SUM(T4.w1_score)+SUM(T4.w2_score));

STORE G2 INTO '$out' USING PigStorage('\t');

